%define major 69
%define minor 1
%define _sbindir %{_bindir}

Name: icu
Version: %{major}.%{minor}
Release: 1
Summary: International Components for Unicode
License: MIT and UCD and Public Domain
URL: http://site.icu-project.org

Source0: https://github.com/unicode-org/icu/releases/download/release-%{major}-%{minor}/icu4c-%{major}_%{minor}-src.tgz

Patch0: icu-remove-gcc-opts.patch

BuildRequires: automake
BuildRequires: pkg-config
BuildRequires: python3

%description
Tools and utilities for developing with icu.


%package -n libicu%{major}
Summary: ICU library

%description -n libicu%{major}
Contains ICU library files


%package devel
Summary: Libicu development files
Requires: libicu%{major} = %{version}-%{release}
Obsoletes: libicu-devel

%description devel
Files needed to build against libicu


%package tools
Summary: Libicu utility tools
Requires: libicu%{major} = %{version}-%{release}
Obsoletes: icu

%description tools
Contains libicu utility tools.


%prep
%setup -q -n icu
%patch0 -p1

%build
cd source
autoreconf -fiv
%configure \
   CFLAGS="$CFLAGS -pthread -fPIC" \
   CXXFLAGS="$CXXFLAGS -std=c++11 -pthread -fPIC" \
   LDFLAGS="-pthread -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
   --enable-shared \
   --disable-static \
   --build=powerpc-ibm-aix6 \
   --host=powerpc-ibm-aix6 \
   #end
%make_build
# Modify pkg-config files to link with the svr4-style libraries
# eg. -licudata67 -> -licudata
# thus linking with libicudata.so -> libicudata.so.67 instead of libicudata67.a
sed -i 's|\(-licu[a-z0-9]*\)%{major}|\1|g' config/*.pc

%check
cd source
make check

%install
cd source
%make_install
# In order for "rpm -i" to work, .a files with major version only cannot be
# symlinks
cd %{buildroot}/%{_libdir}/
mv ./libicudata%{version}.a ./libicudata%{major}.a
mv ./libicui18n%{version}.a ./libicui18n%{major}.a
mv ./libicuio%{version}.a ./libicuio%{major}.a
mv ./libicutest%{version}.a ./libicutest%{major}.a
mv ./libicutu%{version}.a ./libicutu%{major}.a
mv ./libicuuc%{version}.a ./libicuuc%{major}.a
# Remove unnecessary archives
rm -f libicudata.a libicui18n.a libicuio.a libicutest.a libicutu.a libicuuc.a
# For every .a archive create a .so object that does ImpExp of all the symbols
mkdir temp
cd temp
touch empty.c
for LNAME in libicudata libicui18n libicuio libicutest libicutu libicuuc; do
    echo "Processing" $LNAME
    ar -X64 x %{buildroot}/%{_libdir}/${LNAME}%{major}.a
    strip -e $LNAME.so
    ar crlo %{buildroot}/%{_libdir}/${LNAME}%{major}.a $LNAME.so
    dump -nv $LNAME.so | grep EXP | awk '{ print $NF }' | sort | sed '/__dso_handle/d; /__init_aix_libgcc_cxa_atexit/d' > symbols
    (
        echo '#! '"${LNAME}%{major}.a($LNAME.so)"
        echo "# $OBJECT_MODE"
        cat symbols
    ) > shr_64.exp
    (
        echo '#! '"$LNAME.so.%{major}(shr_64.o)"
        echo "# $OBJECT_MODE"
        cat symbols
    ) > shr_64.imp
    gcc --shared -o shr_64.o -Wl,-bI:shr_64.exp,-bE:shr_64.exp -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib empty.c
    strip -e shr_64.o
    ar crlo $LNAME.so.%{major} shr_64.imp shr_64.o
    install -c $LNAME.so.%{major} %{buildroot}/%{_libdir}/
    # create symlink to .so file without libicu major version
    ln -sr %{buildroot}/%{_libdir}/$LNAME.so.%{major} %{buildroot}/%{_libdir}/$LNAME.so
    rm ./$LNAME.so*
done
rm empty.c shr_64.exp shr_64.imp shr_64.o symbols

%files -n libicu%{major}
%defattr(-, qsys, *none)
%{_libdir}/libicudata%{major}.a
%{_libdir}/libicui18n%{major}.a
%{_libdir}/libicuio%{major}.a
%{_libdir}/libicutest%{major}.a
%{_libdir}/libicutu%{major}.a
%{_libdir}/libicuuc%{major}.a
%{_libdir}/libicudata.so.%{major}
%{_libdir}/libicui18n.so.%{major}
%{_libdir}/libicuio.so.%{major}
%{_libdir}/libicutest.so.%{major}
%{_libdir}/libicutu.so.%{major}
%{_libdir}/libicuuc.so.%{major}

%files devel
%defattr(-, qsys, *none)
%{_bindir}/icuinfo
%{_bindir}/makeconv
%{_bindir}/pkgdata
%{_bindir}/uconv
%{_bindir}/icu-config
%{_mandir}/man1/makeconv.1*
%{_mandir}/man1/pkgdata.1*
%{_mandir}/man1/uconv.1*
%{_mandir}/man1/icu-config.1.*
%{_includedir}/unicode
%{_datadir}/%{name}/%{version}/LICENSE
%{_datadir}/%{name}/%{version}/config/mh-aix-gcc
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/mkinstalldirs
%{_libdir}/%{name}/%{version}/Makefile.inc
%{_libdir}/%{name}/%{version}/pkgdata.inc
%{_libdir}/%{name}/Makefile.inc
%{_libdir}/%{name}/pkgdata.inc
%{_libdir}/pkgconfig/icu-i18n.pc
%{_libdir}/pkgconfig/icu-io.pc
%{_libdir}/pkgconfig/icu-uc.pc
%{_libdir}/libicudata.so
%{_libdir}/libicui18n.so
%{_libdir}/libicuio.so
%{_libdir}/libicutest.so
%{_libdir}/libicutu.so
%{_libdir}/libicuuc.so

%files tools
%defattr(-, qsys, *none)
%{_bindir}/derb
%{_bindir}/genbrk
%{_bindir}/gencfu
%{_bindir}/gencnval
%{_bindir}/gendict
%{_bindir}/genrb
%{_bindir}/escapesrc
%{_bindir}/genccode
%{_bindir}/gencmn
%{_bindir}/gennorm2
%{_bindir}/gensprep
%{_bindir}/icupkg
%{_mandir}/man1/derb.1*
%{_mandir}/man1/genbrk.1*
%{_mandir}/man1/gencfu.1*
%{_mandir}/man1/gencnval.1*
%{_mandir}/man1/gendict.1*
%{_mandir}/man1/genrb.1*
%{_mandir}/man8/gencmn.8*
%{_mandir}/man8/genccode.8*
%{_mandir}/man8/gensprep.8*
%{_mandir}/man8/icupkg.8*

%changelog
* Tue Apr 06 2021 Kevin Adler <kadler@us.ibm.com> - 69.1
- Bump to 69.1

* Wed Mar 31 2021 Kevin Adler <kadler@us.ibm.com> - 67.1
- Add obsoletes for previous package names

* Mon Dec 14 2020 Vasili Skurydzin <vasili.skurydzin@ibm.com>
- Add initial spec file
